@@ -804,6 +804,16 @@ void VID_Shutdown (void)
 			SDL_UnlockSurface (screen);
 
 		vid_initialized = 0;
+
+	 	FILE *archivo;
+		char caracteres[100];
+		int c;
+	 	archivo = fopen("/home/user/int_kb_layout","r");
+		do { c = fscanf(archivo, "%s", caracteres); }
+		while (c != EOF); 
+		fclose(archivo);
+		if (caracteres!="us") system("/usr/bin/gconftool-2 -s /apps/osso/inputmethod/int_kb_layout $(cat /home/user/int_kb_layout) -t string");
+
 		SDL_Quit();
 	}
 }
